==> moodle_1.3.1.orig.tar.gz: moodle/lang/th/forum.php <==
<?PHP // $Id: forum.php,v 1.7 2004/03/19 06:30:20 moodler Exp $ 
      // forum.php - created with Moodle 1.2 Beta (2004022400)


$string['addanewdiscussion'] = '駡з';
$string['addanewtopic'] = 'Ǣ';
$string['allowchoice'] = 'ء͡';
$string['allowdiscussions'] = '͹حҵ  $a  ʵ㹡дҹ';
$string['allowratings'] = 'ͧҹṹʵ';
$string['allowsdiscussions'] = 'дҹ͹حҵФö駡з餹˹觡з ';
$string['anyfile'] = 'ء';
$string['attachment'] = 'Attachment';
$string['bynameondate'] = '  $a->name - $a->date';
$string['configdisplaymode'] = 'ʴҷҡաõ駤';
$string['configlongpost'] = 'ʵ㴡ҡҹ ж  (¡ html)';
$string['configmanydiscussions'] = 'ӹǹԴ繷ͧʴ˹˹';
$string['configmaxbytes'] = 'Ҵ٧شöṺŧз';
$string['configshortpost'] = 'ʵ㴡ǵӡҹ ж  (¡ html)';
$string['couldnotadd'] = 'ö ʵͧس  բͼԴҴ';
$string['couldnotdeleteratings'] = ' öź  դṹ º ';
$string['couldnotdeletereplies'] = ' öź դͺº';
$string['couldnotupdate'] = 'ö Ѿഷʵͧس բͼԴҴ';
$string['delete'] = 'ź';
$string['deleteddiscussion'] = 'з١ź';
$string['deletedpost'] = 'ʵ١ź';
$string['deletesure'] = '㨹ҵͧź ʵ';
$string['discussion'] = 'з';
$string['discussionmoved'] = 'з价 \'$a\'';
$string['discussions'] = 'з ';
$string['discussionsstartedby'] = 'з  $a';
$string['discussionsstartedbyrecent'] = 'з駢 ';
$string['discussthistopic'] = 'Ǣ͡з';
$string['eachuserforum'] = '˹觤˹觡з';
$string['edit'] = '';
$string['editing'] = 'ѧ';
$string['emptymessage'] = 'ʵͧسբͼԴҴ ͧǨͺա ˭Թ  ¹ͤ  ѧѹ֡ʵŧҹ';
$string['everyonecanchoose'] = 'ö͡Ҫԡͧдҹ';
$string['everyoneissubscribed'] = 'ءҪԡͧдҹ';
$string['forcesubscribe'] = 'ءͧѤҪԡдҹ';
$string['forcesubscribeq'] = 'ءͧҪԡдҹҹ?';
$string['forum'] = 'дҹǹ';
$string['forumintro'] = 'Ըдҹ';
$string['forumname'] = '͡дҹ';
$string['forums'] = 'дҹ';
$string['forumtype'] = 'ͧдҹ';
$string['generalforum'] = 'дҹ';
$string['generalforums'] = 'дҹ';
$string['inforum'] = ' $a';
$string['intronews'] = '  С';
$string['introsocial'] = 'дҹǹ ẺԴ ö¡ѹءͧ';
$string['introteacher'] = 'дҹѺҹ ͻ֡ͧ¹͹';
$string['lastpost'] = 'ͺش';
$string['learningforums'] = 'дҹ¹͹';
$string['maxattachmentsize'] = 'ҴͧṺ';
$string['maxtimehaspassed'] = '¤ ҷ㹡  ($a) ҹ';
$string['message'] = 'ͤ';
$string['modeflatnewestfirst'] = 'ʴӵͺẺ˹ҡӵͺش';
$string['modeflatoldestfirst'] = 'ʴӵͺẺ˹ҡ ӵͺáش';
$string['modenested'] = 'ʴӵͺ Ẻ˹';
$string['modethreaded'] = 'ʴӵͺ Ẻ繵˹ѧ';
$string['modulename'] = 'дҹǹ';
$string['modulenameplural'] = 'дҹǹҷ';
$string['more'] = '';
$string['movethisdiscussionto'] = '¡з价...';
$string['namenews'] = 'дҹ';
$string['namesocial'] = 'дҹʹ';
$string['nameteacher'] = 'дҹҨ';
$string['newforumposts'] = 'ʵش㹡дҹ';
$string['nodiscussions'] = 'ѧաз';
$string['noguestpost'] = '¤ ؤŷöʵ';
$string['nomorepostscontaining'] = '辺 \'$a\'  ʵ';
$string['nonews'] = 'ѧբ';
$string['noposts'] = 'ʵ';
$string['nopostscontaining'] = 'ʵդ \'$a\' ';
$string['nosubscribers'] = 'ѧҪԡ㹡дҹ';
$string['notingroup'] = '¤ФسͧҪԡ㹡͹֧㹡дҹǹҹ';
$string['nownotsubscribed'] = '$a->name Ѻ ͻҡ \'$a->forum\' ҧ';
$string['nowsubscribed'] = '$a->name Ѻͺҡ \'$a->forum\' ҧ';
$string['numposts'] = '$a ʵ';
$string['olderdiscussions'] = 'з';
$string['openmode0'] = '駡з ͺ';
$string['openmode1'] = '駡з ͺ';
$string['openmode2'] = '駡з ͺ';
$string['parent'] = '繡͹˹';
$string['parentofthispost'] = 'ʵس¹ͺ';
$string['postadded'] = 'ʵͧس<P>س $a ҡͧ';
$string['postincontext'] = 'ʵ';
$string['postmailinfo'] = '繡ͻͤ ҡʵ  $a  䫵
ҡͧõͺԡԧ';
$string['postrating1'] = 'ʴ֧Ẻ¡ǹ';
$string['postrating2'] = 'ӡշẺ¡ǹ§';
$string['postrating3'] = 'ʴ֧Ẻ§';
$string['posts'] = 'ʵ';
$string['postupdated'] = 'ʵͧسѺѾഷ';
$string['processingpost'] = 'ѧԹʵ $a';
$string['rate'] = 'ṹ';
$string['rating'] = 'ṹ';
$string['ratingeveryone'] = 'ءöṹʵ';
$string['ratingno'] = 'աṹ';
$string['ratingonlyteachers'] = '੾ $a  ҹ鹷öṹʵ';
$string['ratingpublic'] = '$a  ö繤ṹͧء';
$string['ratingpublicnot'] = '$a ö繤ṹͧͧ';
$string['ratings'] = 'ṹ';
$string['ratingssaved'] = 'ѹ֡ṹ';
$string['ratingsuse'] = 'ṹ';
$string['ratingtime'] = 'ṹ੾㹪ǧѹ ҵ仹';
$string['re'] = 'ͺ:';
$string['readtherest'] = 'ҹͷ Ǣ͹';
$string['replies'] = 'ͺ';
$string['repliesmany'] = '$a ӵͺ';
$string['repliesone'] = '$a ӵͺ';
$string['reply'] = 'ͺ';
$string['replyforum'] = 'ͺѺдҹ';
$string['search'] = '';
$string['searchforums'] = '';
$string['searcholderposts'] = 'ҡз';
$string['searchresults'] = 'šä';
$string['sendinratings'] = '觤ṹش';
$string['showsubscribers'] = 'ʴҪԡдҹ';
$string['singleforum'] = 'дҹǢҧ';
$string['startedby'] = '';
$string['subject'] = 'Ǣ';
$string['subscribe'] = 'ѤҪԡдҹ';
$string['subscribed'] = 'Ҫԡº';
$string['subscribers'] = 'Ҫԡ';
$string['subscribersto'] = 'Ҫԡͧ \'$a\'';
$string['subscribestart'] = 'ͧʵ㹡зҧ';
$string['subscribestop'] = 'ͧʵҧ';
$string['subscription'] = 'Ҫԡ';
$string['subscriptions'] = 'Ҫԡ';
$string['unsubscribe'] = 'ͧ͡ҡҪԡдҹ';
$string['unsubscribed'] = 'Ҫԡ';
$string['youratedthis'] = 'سṹ';
$string['yournewtopic'] = 'з';
$string['yourreply'] = 'ӵͺ';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/th/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.5 unstable development (2004083000)


$string['addanewdiscussion'] = '駡з';
$string['addanewtopic'] = 'Ǣ';
$string['allowchoice'] = 'ء͡';
$string['allowdiscussions'] = '͹حҵ  $a  ʵ㹡дҹ';
$string['allowratings'] = 'ͧҹṹʵ';
$string['allowsdiscussions'] = 'дҹ͹حҵФö駡з餹˹觡з ';
$string['anyfile'] = 'ء';
$string['attachment'] = 'Ṻ';
$string['bynameondate'] = '  $a->name - $a->date';
$string['configdisplaymode'] = 'ʴҷҡաõ駤';
$string['configenablerssfeeds'] = 'ԪԴ͡͹ RSS   سѧеͧԴ͹Сзͧ';
$string['configlongpost'] = 'ʵ㴡ҡҹж (¡ html)';
$string['configmanydiscussions'] = 'ӹǹԴ繷ͧʴ˹˹';
$string['configmaxbytes'] = 'Ҵ٧شöṺŧз';
$string['configreplytouser'] = '㹡óշӡ͡仵ͧкتͼŢͧҪԡ  ֧Ҫԡзӡë͹Ţͧͧ';
$string['configshortpost'] = 'ʵ㴡ǵӡҹж (¡ html)';
$string['couldnotadd'] = 'ö ʵͧس  բͼԴҴ';
$string['couldnotdeleteratings'] = 'öź դṹº ';
$string['couldnotdeletereplies'] = ' öź դͺº';
$string['couldnotupdate'] = 'ö Ѿഷʵͧس բͼԴҴ';
$string['delete'] = 'ź';
$string['deleteddiscussion'] = 'з١ź';
$string['deletedpost'] = 'ʵ١ź';
$string['deletesure'] = '㨹ҵͧź ʵ';
$string['digestmailheader'] = 'ʷͧзաʵ㹡ôҹ  $a->sitename Ҥسͧ¹ŧ价 go to $a->userprefs';
$string['digestmailprefs'] = 'ѵǹǢͧس';
$string['digestmailsubject'] = 'дҹǹʷѹҡ $a';
$string['digestsentusers'] = 'ʷ $a Ҫԡº';
$string['discussion'] = 'з';
$string['discussionmoved'] = 'з价 \'$a\'';
$string['discussionname'] = '͡з';
$string['discussions'] = 'з';
$string['discussionsstartedby'] = '駡з $a';
$string['discussionsstartedbyrecent'] = '駡зش';
$string['discussthistopic'] = 'ͺз';
$string['eachuserforum'] = '˹觤˹觡з';
$string['edit'] = '';
$string['editing'] = 'ѧ';
$string['emptymessage'] = 'ʵͧسբͼԴҴ ͧǨͺա˭Թ¹ͤ  ѧѹ֡ʵŧҹ';
$string['everyonecanchoose'] = 'Ҫԡö͡Ҫԡͧдҹ';
$string['everyoneissubscribed'] = 'ءҪԡͧдҹ';
$string['existingsubscribers'] = 'Ҫԡ';
$string['forcesubscribe'] = 'ءͧѤҪԡдҹ';
$string['forcesubscribeq'] = 'ءͧҪԡдҹҹ?';
$string['forum'] = 'дҹǹ';
$string['forumintro'] = 'Ըдҹ';
$string['forumname'] = '͡дҹ';
$string['forums'] = 'дҹǹ';
$string['forumtype'] = 'ͧдҹ';
$string['generalforum'] = 'дҹ';
$string['generalforums'] = 'дҹ';
$string['inforum'] = ' $a';
$string['intronews'] = 'лС';
$string['introsocial'] = 'дҹǹẺԴö¡ѹءͧ';
$string['introteacher'] = 'дҹѺҹ ͻ֡ͧ¹͹';
$string['lastpost'] = 'ͺش';
$string['learningforums'] = 'дҹ¹͹';
$string['maxattachmentsize'] = 'Ҵͧ٧ش';
$string['maxtimehaspassed'] = '¤ ҷ㹡  ($a) ҹ';
$string['message'] = 'ͤ';
$string['modeflatnewestfirst'] = 'ʴӵͺẺ˹ҡӵͺش';
$string['modeflatoldestfirst'] = 'ʴӵͺẺ˹ҡ ӵͺáش';
$string['modenested'] = 'ʴӵͺẺ˹';
$string['modethreaded'] = 'ʴӵͺẺ˹ѧ';
$string['modulename'] = 'дҹǹ';
$string['modulenameplural'] = 'дҹǹ';
$string['more'] = '';
$string['movethisdiscussionto'] = '¡з价...';
$string['namenews'] = 'дҹ';
$string['namesocial'] = 'дҹʹ';
$string['nameteacher'] = 'дҹҨ';
$string['newforumposts'] = 'ʵش㹡дҹ';
$string['nodiscussions'] = 'ѧաз';
$string['noguestpost'] = '¤ ؤŷöʵ';
$string['nomorepostscontaining'] = '辺 \'$a\'  ʵ';
$string['nonews'] = 'ѧբ';
$string['noposts'] = 'ʵ';
$string['nopostscontaining'] = 'ʵդ \'$a\' ';
$string['nosubscribers'] = 'ѧҪԡ㹡дҹ';
$string['notingroup'] = '¤ФسͧҪԡ㹡͹֧㹡дҹǹҹ';
$string['nownotsubscribed'] = '$a->name ѺҨҡ \'$a->forum\' ҧ';
$string['nowsubscribed'] = '$a->name ѺҨҡ \'$a->forum\' ҧ';
$string['numposts'] = '$a ʵ';
$string['olderdiscussions'] = 'з';
$string['openmode0'] = '駡з ͺ';
$string['openmode1'] = '駡з ͺ';
$string['openmode2'] = '駡з ͺ';
$string['parent'] = '繡͹˹';
$string['parentofthispost'] = 'ʵس¹ͺ';
$string['postadded'] = 'ʵͧس<P>س $a ҡͧ';
$string['postincontext'] = 'ʵ';
$string['postmailinfo'] = '繡ͻͤ ҡʵ  $a  䫵
ҡͧõͺԡԧ';
$string['postrating1'] = 'ʴ֧Ẻ¡ǹ';
$string['postrating2'] = 'ӡշẺ¡ǹ§';
$string['postrating3'] = 'ʴ֧Ẻ§';
$string['posts'] = 'ʵ';
$string['posttoforum'] = 'ʵŧдҹǹ';
$string['postupdated'] = 'ʵͧسѺѾഷ';
$string['potentialsubscribers'] = 'öҪԡ';
$string['processingdigest'] = 'ԹšѺ $a';
$string['processingpost'] = 'ѧԹʵ $a';
$string['prune'] = '¡';
$string['prunedpost'] = 'зҧ鹨ҡʵѧ';
$string['pruneheading'] = '¡ʵѵѵǷӡѧз';
$string['rate'] = 'ṹ';
$string['rating'] = 'ṹ';
$string['ratingeveryone'] = 'ءöṹʵ';
$string['ratingno'] = 'աṹ';
$string['ratingonlyteachers'] = '੾Ҩҹ鹷öṹʵ';
$string['ratingpublic'] = '$a  ö繤ṹͧء';
$string['ratingpublicnot'] = '$a ö繤ṹͧͧ';
$string['ratings'] = 'ṹ';
$string['ratingssaved'] = 'ѹ֡ṹ';
$string['ratingsuse'] = 'ṹ';
$string['ratingtime'] = 'ṹ੾㹪ǧѹ ҵ仹';
$string['re'] = 'ͺ:';
$string['readtherest'] = 'ҹͷ Ǣ͹';
$string['replies'] = 'ͺ';
$string['repliesmany'] = '$a ӵͺ';
$string['repliesone'] = '$a ӵͺ';
$string['reply'] = 'ͺ';
$string['replyforum'] = 'ͺѺдҹ';
$string['rsssubscriberssdiscussions'] = 'ʴ RSS Ѻ\'$a\'  ʹ ';
$string['rsssubscriberssposts'] = 'ʴ RSS Ѻ \'$a\' ʵ';
$string['search'] = '';
$string['searchforums'] = '';
$string['searcholderposts'] = 'ҡз';
$string['searchresults'] = 'šä';
$string['sendinratings'] = '觤ṹش';
$string['showsubscribers'] = 'ʴҪԡдҹ';
$string['singleforum'] = 'дҹǢҧ';
$string['startedby'] = '';
$string['subject'] = 'Ǣ';
$string['subscribe'] = 'ѤҪԡдҹ';
$string['subscribeall'] = 'Ѥ÷ءз';
$string['subscribed'] = 'Ҫԡº';
$string['subscribenone'] = 'ͧҷء͡ҡҪԡз';
$string['subscribers'] = 'Ҫԡ';
$string['subscribersto'] = 'Ҫԡͧ \'$a\'';
$string['subscribestart'] = 'ͧʵ㹡зҧ';
$string['subscribestop'] = 'ͧʵҧ';
$string['subscription'] = 'Ҫԡ';
$string['subscriptions'] = 'Ҫԡ';
$string['unsubscribe'] = 'ͧ͡ҡҪԡдҹ';
$string['unsubscribed'] = 'Ҫԡ';
$string['unsubscribeshort'] = '¡ԡҪԡ';
$string['yesforever'] = ' ʹ';
$string['yesinitially'] = ' ͹ҹ';
$string['youratedthis'] = 'سṹ';
$string['yournewtopic'] = 'з';
$string['yourreply'] = 'ӵͺ';

?>
